@@ -10,7 +10,11 @@ from perun.proxygui.gui.gui import construct_gui_blueprint
 
 def get_config():
     try:
-        with open("/etc/perun.proxygui.yaml", "r") as ymlfile:
+        with open(
+            "/etc/perun.proxygui.yaml",
+            "r",
+            encoding="utf8",
+        ) as ymlfile:
             cfg = yaml.safe_load(ymlfile)
     except IOError:
         with open(
