@@ -4,17 +4,17 @@ from unittest.mock import patch
 import pytest
 
 from perun.proxygui.app import get_config, get_flask_app
-from perun.proxygui.tests.shared_test_data import GLOBAL_CONFIG
+from perun.proxygui.tests.shared_test_data import SHARED_TESTING_CONFIG
 
 
 @pytest.fixture()
 def client():
     with patch(
         "perun.utils.ConfigStore.ConfigStore.get_global_cfg",
-        return_value=GLOBAL_CONFIG,
+        return_value=SHARED_TESTING_CONFIG,
     ), patch(
         "perun.utils.ConfigStore.ConfigStore.get_attributes_map",
-        return_value=GLOBAL_CONFIG,
+        return_value=SHARED_TESTING_CONFIG,
     ):
         cfg = get_config()
         app = get_flask_app(cfg)
